@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -62,6 +34,7 @@ import static com.openexchange.webdav.client.PropertyName.DAV_GETCONTENTTYPE;
 import static com.openexchange.webdav.client.PropertyName.DAV_GETETAG;
 import static com.openexchange.webdav.client.PropertyName.DAV_GETLASTMODIFIED;
 import static com.openexchange.webdav.client.PropertyName.DAV_LOCKDISCOVERY;
+import static com.openexchange.webdav.client.PropertyName.DAV_RESOURCETYPE;
 import static com.openexchange.webdav.client.WebDAVClient.DEPTH_0;
 import static com.openexchange.webdav.client.WebDAVClient.DEPTH_1;
 import static com.openexchange.webdav.client.WebDAVClient.DEPTH_INFINITY;
@@ -198,7 +171,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
             return saveDocument(file, null, sequenceNumber, modifiedFields);
         }
         WebDAVPath path = getWebDAVPath(file.getFolderId(), file.getId());
-        List<Field> fieldsToUpdate = new ArrayList<Field>(null == modifiedFields ? Arrays.asList(Field.values()) : modifiedFields);
+        List<Field> fieldsToUpdate = new ArrayList<>(null == modifiedFields ? Arrays.asList(Field.values()) : modifiedFields);
         /*
          * check for rename through update, first
          */
@@ -225,8 +198,8 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
              */
             return newFileId;
         }
-        Map<QName, Object> propsToSet = new HashMap<QName, Object>();
-        Set<QName> propsToRemove = new HashSet<QName>();
+        Map<QName, Object> propsToSet = new HashMap<>();
+        Set<QName> propsToRemove = new HashSet<>();
         for (Entry<QName, Object> entry : props.entrySet()) {
             if (null == entry.getValue()) {
                 propsToRemove.add(entry.getKey());
@@ -336,7 +309,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
 
     @Override
     public IDTuple saveDocument(File file, InputStream data, long sequenceNumber, List<Field> modifiedFields) throws OXException {
-        List<Field> fieldsToUpdate = new ArrayList<Field>(null == modifiedFields ? Arrays.asList(Field.values()) : modifiedFields);
+        List<Field> fieldsToUpdate = new ArrayList<>(null == modifiedFields ? Arrays.asList(Field.values()) : modifiedFields);
         WebDAVPath path = null;
         if (NEW == file.getId()) {
             /*
@@ -427,7 +400,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
         /*
          * update metadata as needed
          */
-        fieldsToUpdate = Field.reduceBy(fieldsToUpdate, Field.FOLDER_ID, Field.FILE_MIMETYPE, Field.FILE_SIZE, Field.FILENAME);
+        fieldsToUpdate = Field.reduceBy(fieldsToUpdate, Field.FOLDER_ID, Field.FILE_MIMETYPE, Field.FILE_SIZE, Field.FILENAME, Field.UNIQUE_ID);
         return saveFileMetadata(file, sequenceNumber, fieldsToUpdate);
     }
 
@@ -438,7 +411,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
 
     public void removeDocument(String folderId, long sequenceNumber, boolean hardDelete) throws OXException {
         SearchIterator<File> iterator = getDocuments(folderId).results();
-        List<IDTuple> ids = new ArrayList<FileStorageFileAccess.IDTuple>();
+        List<IDTuple> ids = new ArrayList<>();
         try {
             while (iterator.hasNext()) {
                 File document = iterator.next();
@@ -457,7 +430,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
 
     @Override
     public List<IDTuple> removeDocument(List<IDTuple> ids, long sequenceNumber, boolean hardDelete) throws OXException {
-        List<IDTuple> notDeleted = new ArrayList<IDTuple>();
+        List<IDTuple> notDeleted = new ArrayList<>();
         for (IDTuple id : ids) {
             try {
                 //Check for a conflict by comparing the sequence number (last_modified time stamp) with the sequence number given
@@ -470,7 +443,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
                     //Conflict
                     notDeleted.add(id);
                 }
-            } catch (OXException e) {
+            } catch (@SuppressWarnings("unused") OXException e) {
                 notDeleted.add(id);
             }
         }
@@ -505,7 +478,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
             }
             throw asOXException(e);
         }
-        List<File> files = new ArrayList<File>();
+        List<File> files = new ArrayList<>();
         for (WebDAVResource resource : resources) {
             if (false == resource.isCollection()) {
                 files.add(getWebDAVFile(resource));
@@ -522,8 +495,10 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
      *
      * @param resource The WebDAV resource to create the file storage file from
      * @return The file storage file
-     * @throws OXException
+     * @throws UnsupportedOperationException if the specified resource is a collection
+     * @throws OXException if any other error is occurred
      */
+    @SuppressWarnings("unused")
     protected WebDAVFile getWebDAVFile(WebDAVResource resource) throws OXException {
         if (resource.isCollection()) {
             throw new UnsupportedOperationException();
@@ -604,7 +579,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
 
     @Override
     public Map<String, Long> getSequenceNumbers(List<String> folderIds) throws OXException {
-        Map<String, Long> sequenceNumbers = new HashMap<String, Long>(folderIds.size());
+        Map<String, Long> sequenceNumbers = new HashMap<>(folderIds.size());
         Set<QName> props = Collections.singleton(PropertyName.DAV_GETETAG);
         for (String folderId : folderIds) {
             WebDAVPath path = getWebDAVPath(folderId);
@@ -651,7 +626,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
             throw asOXException(e);
         }
 
-        List<File> files = new ArrayList<File>();
+        List<File> files = new ArrayList<>();
         for (WebDAVResource resource : resources) {
             if (false == resource.isCollection()) {
                 files.add(getWebDAVFile(resource));
@@ -819,7 +794,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
         if (null != requestedSortBy) {
             fields.add(requestedSortBy);
         }
-        HashSet<QName> props = new HashSet<QName>(fields.size() + 1);
+        HashSet<QName> props = new HashSet<>(fields.size() + 1);
         props.add(DAV_GETETAG);
         for (Field field : fields) {
             switch (field) {
@@ -850,7 +825,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
     }
 
     protected Map<QName, Object> getPropertiesToSet(File file, Collection<Field> indicatedFields) {
-        Map<QName, Object> props = new HashMap<QName, Object>();
+        Map<QName, Object> props = new HashMap<>();
         Set<Field> fields = null == indicatedFields ? EnumSet.allOf(Field.class) : indicatedFields.isEmpty() ? EnumSet.noneOf(Field.class) : EnumSet.copyOf(indicatedFields);
         for (Field field : fields) {
             switch (field) {
@@ -897,7 +872,7 @@ public abstract class AbstractWebDAVFileAccess extends AbstractWebDAVAccess impl
     private String optName(String folderId, String fileId) {
         try {
             return getWebDAVPath(folderId, fileId).getName();
-        } catch (Exception e) {
+        } catch (@SuppressWarnings("unused") Exception e) {
             return fileId;
         }
     }
